This function is analogous to all mo_* functions of the AMR package, see AMR::mo_property().
mo_glims(
x,
language = AMR::get_AMR_locale(),
keep_synonyms = getOption("AMR_keep_synonyms", FALSE),
...
)Any character (vector) that can be coerced to a valid microorganism code with as.mo(). Can be left blank for auto-guessing the column containing microorganism codes if used in a data set, see Examples.
Language to translate text like "no growth", which defaults to the system language (see get_AMR_locale()).
A logical to indicate if outdated, previously valid taxonomic names must be preserved and not be corrected to currently accepted names. Do note that the term "synonym" is in this case jargon from the field of microbial taxonomy - it is not in place to denote that e.g. "Streptococcus Group A" is a synonym of S. pyogenes. Though this is practically the case, taxonomically it is not as "Streptococcus Group A" is not even a valid taxonomic name.
The default is FALSE, which will return a note if outdated taxonomic names were processed. The default can be set with the package option AMR_keep_synonyms, i.e. options(AMR_keep_synonyms = TRUE) or options(AMR_keep_synonyms = FALSE).
Other arguments passed on to as.mo(), such as 'minimum_matching_score', 'ignore_pattern', and 'remove_from_input'.
mo_glims("E. coli")
#> [1] "Eschcl"
library(dplyr, warn.conflicts = FALSE)
data.frame(mo = c("ESCCOL", "Staph aureus")) |>
mutate(glims = mo_glims())
#> i Using column 'mo' as input for `mo_name()`
#> mo glims
#> 1 ESCCOL Eschcl
#> 2 Staph aureus Stphars
# even works for non-existing entries in AMR package
mo_glims("Streptococcus mitis/oralis")
#> [1] "Strpmi/or"
if (require(AMR, warn.conflicts = FALSE)) {
as.mo("Streptococcus mitis/oralis")
}
#> Loading required package: AMR
#> Class 'mo'
#> [1] CUSTOM615_STRPT_MTS/
if (require("AMR")) {
mo_genus("Streptococcus mitis/oralis")
}
#> [1] "Streptococcus"
if (require("AMR")) {
mo_gramstain("Streptococcus mitis/oralis")
}
#> [1] "Gram-positive"