Generates hashes with or without an extra key/salt. This key defaults to the project identifier.
generate_hash(x, key = TRUE, bits = 256)input, will be converted to character
key or salt. Use TRUE (default) to use the project identifier that will be printed to the Console, or any character to use as key/salt, or use NULL or FALSE to not use a key.
number of bits, often one of: 224, 256, 384, 512
This function uses the openssl::sha2() function for the hashing, but always returns a character vector.
generate_hash("a")
#> Using {certeprojects} project identifier as hash key: "runner-2608291201".
#> [1] "2c09df6bd69b857947b741ec7d846cd46be7ad0157b433a66891e9cf3130cb3c"
generate_hash(c("a", "b", "c"))
#> Using {certeprojects} project identifier as hash key: "runner-2608291201".
#> [1] "2c09df6bd69b857947b741ec7d846cd46be7ad0157b433a66891e9cf3130cb3c"
#> [2] "52a1d44eaf1271b200bf4a3f209a23409becba10f2e4eff3d426bee29c493bf6"
#> [3] "996e49da86dcc1b28216f8fdcddeff40c2e075441bb9f34b470b0263b4a42d66"
generate_hash("a", "secret")
#> [1] "4048c44911916043ff626895ff78c5262764685b6cb9a03ce07886a9effb924c"
generate_hash(c("a", "b", "c"), "secret")
#> [1] "4048c44911916043ff626895ff78c5262764685b6cb9a03ce07886a9effb924c"
#> [2] "8caf295837e09c876c0c5ef729581d5e75ef93adc10420ce71aab05636ac63ed"
#> [3] "ef006b65b8ce49c891479554278e47e7d76735e7ddd6392fc68342322f39e3c4"