Generates hashes with or without an extra key/salt. This key defaults to the project identifier.
generate_hash(x, key = TRUE, bits = 256)input, will be converted to character
key or salt. Use TRUE (default) to use the project identifier that will be printed to the Console, or any character to use as key/salt, or use NULL or FALSE to not use a key.
number of bits, often one of: 224, 256, 384, 512
This function uses the openssl::sha2() function for the hashing, but always returns a character vector.
generate_hash("a")
#> Using {certeprojects} project identifier as hash key: "runner-2608130828".
#> [1] "135e19a62f219ebbacf55e4c1950932236897ac8be91dafb06ca66a96a7d7416"
generate_hash(c("a", "b", "c"))
#> Using {certeprojects} project identifier as hash key: "runner-2608130828".
#> [1] "135e19a62f219ebbacf55e4c1950932236897ac8be91dafb06ca66a96a7d7416"
#> [2] "a9b702ea02c1423302e56eee898417bb0ad956725464b60ae09e6af8c0d9f230"
#> [3] "7275595e434c8dbcfb6eacb52a05b84371a939381c1a3b7ec02059f09c4b61d8"
generate_hash("a", "secret")
#> [1] "4048c44911916043ff626895ff78c5262764685b6cb9a03ce07886a9effb924c"
generate_hash(c("a", "b", "c"), "secret")
#> [1] "4048c44911916043ff626895ff78c5262764685b6cb9a03ce07886a9effb924c"
#> [2] "8caf295837e09c876c0c5ef729581d5e75ef93adc10420ce71aab05636ac63ed"
#> [3] "ef006b65b8ce49c891479554278e47e7d76735e7ddd6392fc68342322f39e3c4"