Generates hashes with or without an extra key/salt. This key defaults to the project identifier.
generate_hash(x, key = TRUE, bits = 256)input, will be converted to character
key or salt. Use TRUE (default) to use the project identifier that will be printed to the Console, or any character to use as key/salt, or use NULL or FALSE to not use a key.
number of bits, often one of: 224, 256, 384, 512
This function uses the openssl::sha2() function for the hashing, but always returns a character vector.
generate_hash("a")
#> Using {certeprojects} project identifier as hash key: "runner-2605210751".
#> [1] "d1281e9c6695428aa6b000cb2a400e903194908fd95a8fb6dadc9dd9f5d58404"
generate_hash(c("a", "b", "c"))
#> Using {certeprojects} project identifier as hash key: "runner-2605210751".
#> [1] "d1281e9c6695428aa6b000cb2a400e903194908fd95a8fb6dadc9dd9f5d58404"
#> [2] "4e3de7d97f3de9f1235aa45c96b69df902d5e63666a09e9724aab44e45bca63f"
#> [3] "707a93093b184c6a18cb1a308370790a072410cbe2ea405222177f871de62aea"
generate_hash("a", "secret")
#> [1] "4048c44911916043ff626895ff78c5262764685b6cb9a03ce07886a9effb924c"
generate_hash(c("a", "b", "c"), "secret")
#> [1] "4048c44911916043ff626895ff78c5262764685b6cb9a03ce07886a9effb924c"
#> [2] "8caf295837e09c876c0c5ef729581d5e75ef93adc10420ce71aab05636ac63ed"
#> [3] "ef006b65b8ce49c891479554278e47e7d76735e7ddd6392fc68342322f39e3c4"