Generates hashes with or without an extra key/salt. This key defaults to the project identifier.
generate_hash(x, key = TRUE, bits = 256)input, will be converted to character
key or salt. Use TRUE (default) to use the project identifier that will be printed to the Console, or any character to use as key/salt, or use NULL or FALSE to not use a key.
number of bits, often one of: 224, 256, 384, 512
This function uses the openssl::sha2() function for the hashing, but always returns a character vector.
generate_hash("a")
#> Using {certeprojects} project identifier as hash key: "runner-2603171355".
#> [1] "48ed61e585119ff0987ccfaa8e9658284ccf654ba8e64afeeb5813c2f89a1652"
generate_hash(c("a", "b", "c"))
#> Using {certeprojects} project identifier as hash key: "runner-2603171355".
#> [1] "48ed61e585119ff0987ccfaa8e9658284ccf654ba8e64afeeb5813c2f89a1652"
#> [2] "b9d0aaf66e14088f1c3b0816ba28d7fbeb39e397e4ffade905e8c7b6183a8008"
#> [3] "1b3112dbfdb508a393c18b6f2e21d81d46e306c52cb16056920de04ca6350a23"
generate_hash("a", "secret")
#> [1] "4048c44911916043ff626895ff78c5262764685b6cb9a03ce07886a9effb924c"
generate_hash(c("a", "b", "c"), "secret")
#> [1] "4048c44911916043ff626895ff78c5262764685b6cb9a03ce07886a9effb924c"
#> [2] "8caf295837e09c876c0c5ef729581d5e75ef93adc10420ce71aab05636ac63ed"
#> [3] "ef006b65b8ce49c891479554278e47e7d76735e7ddd6392fc68342322f39e3c4"